function [] = savetikzplots(),
   savetikzplot('tikzplotdata0.txt', @myfun, 50, -3, 3);
   % empirical cdf for a 10-point sample from the Gaussian distribution:
   sample1 = mynormalgenerator(10);
   savetikzplotecdf('tikzplotdata1.txt', sample1, -3, 3);
   % empirical cdf for a 15-point sample from the discrete distribution with values 0, 1/10, ..., 9/10:
   sample2 = mydecimalgenerator(15);
   savetikzplotecdf('tikzplotdata2.txt', sample2, -0.3, 1.3);
end

% If you find this file useful, then please put somewhere a reference to my site:
% Egor Maximenko, Programacion en Matlab, http://esfm.egormaximenko.com/matlab.html

function [] = savetikzplot(filename, fhandle, nparts, xmin, xmax),
   x = linspace(xmin, xmax, nparts + 1)';
   y = fhandle(x);
   data = [x, y];
   fileID = fopen(filename, 'w');
   fprintf(fileID, 'This file is generated by the program savetikzplots.m.\n');
   fprintf(fileID, 'The following data must be included manually to the TikZ picture.\n');
   fprintf(fileID, '(%.4f,%.4f)\n', data');
   fclose(fileID);
end

function [] = savetikzplotecdf(filename, sample, xmin, xmax),
   npoints = length(sample);
   samples = max(xmin, sample);
   samples = min(xmax, sample);
   [x, I, J] = unique(sample);
   freqs = accumarray(J, 1);
   y = cumsum(freqs) / npoints;
   y0 = (x(1) == xmin) * y(1);
   y = [y0; y];
   xbegin = [xmin; x];
   xend = [x; xmax];
   data = [xbegin, xend, y];
   fileID = fopen(filename, 'w');
   fprintf(fileID, 'This file is generated by the program savetikzplots.m.\n');
   fprintf(fileID, 'The following data must be included manually to the TikZ picture.\n');
   fprintf(fileID, '%.4f/%.4f/%.4f,\n', data(1 : (end - 1), :)');
   fprintf(fileID, '%.4f/%.4f/%.4f\n', data(end, :)');
   fclose(fileID);
end

% Here are two trivial examples of random generators
function [sample] = mynormalgenerator(npoints),
   sample = randn(npoints, 1);
end

function [sample] = mydecimalgenerator(npoints),
   sample = floor(rand(npoints, 1) * 10) / 10;
end

% Here is an example of function definition.
% The function fun must be "vectorized",
% i.e. x can be a vector (or a matrix),
% myfun is applied to each component separately
% and returns the array of the same size as x.
% Pointwise operations like .* and .^ can be useful.

function [y] = myfun(x),
   y = normcdf(x);
end
